import os

from bluer_objects import storage, mlflow

os.environ["MLFLOW_TRACKING_URI"] = os.path.join(
    os.environ.get("HOME"),
    "mlruns",
)


def upload(object_name: str) -> bool:
    return storage.upload(object_name) and mlflow.log_run(object_name)



from blueness.pypi import setup

from bluer_sandbox import NAME, VERSION, DESCRIPTION, REPO_NAME

setup(
    filename=__file__,
    repo_name=REPO_NAME,
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    packages=[
        NAME,
        f"{NAME}.help",
    ],
    include_package_data=True,
    package_data={
        NAME: [
            "config.env",
            ".abcli/**/*.sh",
            "assets/*",
        ],
    },
)



from typing import List

from bluer_options.terminal import show_usage, xtra
from bluer_ai.help.generic import help_functions as generic_help_functions
from bluer_sandbox.help.notebooks import help_functions as help_notebooks

from bluer_sandbox import ALIAS


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "actions|repo"

    return show_usage(
        [
            "@sandbox",
            "browse",
            f"[{options}]",
        ],
        "browse bluer_sandbox.",
        mono=mono,
    )


help_functions = generic_help_functions(plugin_name=ALIAS)

help_functions.update(
    {
        "browse": help_browse,
        "notebooks": help_notebooks,
    }
)
